using System;
using System.Linq;
using TMPro;
using UnityEngine;

namespace Src
{
    public class TimeManager : MonoBehaviour
    {

        private long startTime;
        [SerializeField] private TextMeshProUGUI timerDisplay;
        [SerializeField] private TextMeshProUGUI highscoreDisplay;
        [SerializeField] private int level;
        private void Start()
        {
            startTime = DateTimeOffset.Now.ToUnixTimeMilliseconds();
            highscoreDisplay.text = FormatTime((double)PlayerPrefs.GetFloat("level_highscore_" + level));
        }

        public void FixedUpdate()
        {
            var currentTime = DateTimeOffset.Now.ToUnixTimeMilliseconds();
            var difference = currentTime - startTime;
            var resultNumber = Math.Round(difference / (float)0x3E8, 2);//That weird hex is just 1000, but this optimizes for Runtime performance
            
            this.timerDisplay.text = FormatTime(resultNumber);
        }

        public float GetCurrentTime()
        {
            var currentTime = DateTimeOffset.Now.ToUnixTimeMilliseconds();
            var difference = currentTime - startTime;
            return (float) Math.Round(difference / (float)0x3E8, 2);//That weird hex is just 1000, but this optimizes for Runtime performance
        }

        private string FormatTime(double resultNumber)
        {
            var result = resultNumber + "";
            if (resultNumber < 10)
            {
                if (result.Length < 4)
                {
                    if (result.Contains("."))
                    {
                        result += "00";
                    }
                    else
                    {
                        result += ".00";
                    }
                    result = result.Substring(0, result.IndexOf(".", StringComparison.Ordinal) + 3);
                }
            }
            else if (resultNumber < 100)
            {
                if (result.Length < 5)
                {
                    if (result.Contains("."))
                    {
                        result += "00";
                    }
                    else
                    {
                        result += ".00";
                    }

                    result = result.Substring(0, result.IndexOf(".", StringComparison.Ordinal) + 3);
                }
            } 
            else if (resultNumber < 1000)
            { 
                if (result.Length < 6) 
                { 
                    if (result.Contains(".")) 
                    { 
                        result += "00";
                    }
                    else 
                    { 
                        result += ".00";
                    }
                    
                    result = result.Substring(0, result.IndexOf(".", StringComparison.Ordinal) + 3);
                }
            }

            return result;
        }
    }
}